# -*- coding: utf-8 -*-
"""
Global configuration file for TG2-specific settings in raffle.

This file complements development/deployment.ini.

Please note that **all the argument values are strings**. If you want to
convert them into boolean, for example, you should use the
:func:`paste.deploy.converters.asbool` function, as in::
    
    from paste.deploy.converters import asbool
    setting = asbool(global_conf.get('the_setting'))
 
"""

# Uncomment the following lines to auth against the Fedora Account System
from bunch import Bunch
from fedora.tg2.utils import add_fas_auth_middleware

from tg.configuration import AppConfig

import raffle
from raffle import model
from raffle.lib import app_globals, helpers 

base_config = AppConfig()

# Comment the following lines to auth against the database instead of the
# Fedora Account System Use https://fakefas.fedoraproject.org/accounts or
# another testing fas provider and set insecure=True if you're testing during
# development of the app
class MyAppConfig(AppConfig):
    fas_auth = Bunch(fas_url='https://admin.fedoraproject.org/accounts', insecure=False)
    add_auth_middleware = add_fas_auth_middleware
base_config = MyAppConfig()

base_config.renderers = []

base_config.package = raffle

#Enable json in expose
base_config.renderers.append('json')
#Set the default renderer
base_config.default_renderer = 'mako'
base_config.renderers.append('mako')

#Configure the base SQLALchemy Setup
base_config.use_sqlalchemy = True
base_config.model = raffle.model
base_config.DBSession = raffle.model.DBSession

# Configure the authentication backend

# YOU MUST CHANGE THIS VALUE IN PRODUCTION TO SECURE YOUR APP 
base_config.sa_auth.cookie_secret = "ChangeME" 

base_config.auth_backend = 'sqlalchemy'
base_config.sa_auth.dbsession = model.DBSession
# what is the class you want to use to search for users in the database
base_config.sa_auth.user_class = model.User
# what is the class you want to use to search for groups in the database
base_config.sa_auth.group_class = model.Group
# what is the class you want to use to search for permissions in the database
base_config.sa_auth.permission_class = model.Permission

# override this if you would like to provide a different who plugin for
# managing login and logout of your application
base_config.sa_auth.form_plugin = None

# override this if you are using a different charset for the login form
base_config.sa_auth.charset = 'utf-8'

# You may optionally define a page where you want users to be redirected to
# on login:
base_config.sa_auth.post_login_url = '/post_login'

# You may optionally define a page where you want users to be redirected to
# on logout:
base_config.sa_auth.post_logout_url = '/post_logout'
