# -*- coding: utf-8 -*-
"""Sample model module."""

from sqlalchemy import Column, ForeignKey
from sqlalchemy.orm import backref
try:
    # SA 0.6 +
    from sqlalchemy.orm import relationship
except ImportError:
    from sqlalchemy.orm import relation as relationship
from sqlalchemy.types import Integer, UnicodeText

try:
    # SA 0.6 +
    from sqlalchemy.types import Enum
except ImportError:
    Enum = None
    from sqlalchemy.schema import CheckConstraint

try:
    # SA 0.6 +
    from sqlalchemy.types import LargeBinary
except ImportError:
    from sqlalchemy.types import Binary as LargeBinary
 
from raffle.model import DeclarativeBase
from raffle.model import Ticket

class Prize(DeclarativeBase):
    __tablename__ = 'prize'

    id = Column(Integer, primary_key=True)
    raffle_id = Column(Integer, ForeignKey('raffle.id'), nullable=False)
    prize_info_id = Column(Integer, ForeignKey('prize_info.id'), nullable=False)
    winner = Column(Integer, ForeignKey('ticket.id'), nullable=True)
    ticket = relationship(Ticket, backref=backref('prize'))

class PrizeInfo(DeclarativeBase):
    __tablename__ = 'prize_info'

    id = Column(Integer, primary_key=True)
    name = Column(UnicodeText, nullable=False, unique=True)
    description = Column(UnicodeText)
    try:
        type = Column(Enum(u't-shirt', u'other', name='prize_type'), nullable=False, default=u'other')
    except TypeError:
        type = Column(UnicodeText, nullable=False, default=u'other')
        __table_args__ = (CheckConstraint("type in ('t-shirt', 'other')"), {})

    prizes = relationship(Prize, backref=backref('prize_info'))

class PrizeImage(DeclarativeBase):
    __tablename__ = 'prize_image'

    id = Column(Integer, primary_key=True)
    prize_info_id = Column(Integer, ForeignKey('prize_info.id'))
    image = Column(LargeBinary, nullable=False)
    mimetype = Column(UnicodeText)
    thumbnail = Column(LargeBinary)
    caption = Column(UnicodeText, nullable=True)

    prize_info = relationship(PrizeInfo, backref=backref('images'))

