# -*- coding: utf-8 -*-
"""Sample model module."""

from sqlalchemy import ForeignKey, Column
from sqlalchemy.types import Integer, UnicodeText

from raffle.model import DeclarativeBase

class Ticket(DeclarativeBase):
    __tablename__ = 'ticket'

    id = Column(Integer, primary_key=True)
    person = Column(UnicodeText, nullable=False)
    raffle_id = Column(Integer, ForeignKey('raffle.id'), nullable=False)

class PeopleData(DeclarativeBase):
    '''Hold user information for specific types of raffles

    This table has information that a raffle may collect in order to issue
    prizes efficiently.  For instance T-Shirt size may be collected here.

    :data: is noramlly a json encoded dictionary but any character-based
        string is accepted if it has code that knows how to use it.
    '''
    __tablename__ = 'people_data'

    person = Column(UnicodeText, nullable=False)
    raffle_id = Column(Integer, ForeignKey('raffle.id'))
    data = Column(UnicodeText, nullable=False)

    __mapper_args__ = {'primary_key': (raffle_id, person)}
