## Need TG-2.1.x
##<%inherit file="local:templates.master"/>
<%inherit file="raffle.templates.master"/>

<%!
import datetime
import re

now = datetime.datetime.utcnow()

sanity_re = re.compile(r'<script>', re.I)

def sanity_filter(text):
  '''This function is not guaranteed to find every problematic piece of text.
  It is meant to be run on data that is supposed to come from a trusted source
  to just find things that are way out of the ordinary.
  '''
  if sanity_re.search(text):
    text =  _('Please contact admin@fedoraproject.org to look at issues with'
        ' raffle %(title)s') % {'title': raffle.title}
  return '<div>\n%s\n</div>' % text
%>

<%def name="title()">
  ${raffle.title}
</%def>

<%def name="format_date(date)">
${date.strftime('%Y-%m-%d')}
</%def>

${parent.sidebar_top()}

<div id="content">
<h2>${raffle.title}</h2>
<table class="raffleinfo" style="float:left;">
  <tr>
    <th>Start date:</th>
    <td>${format_date(raffle.start_date)}</td>
    </tr><tr>
    <th>End date:</th>
    <td>${format_date(raffle.end_date)}</td>
    </tr><tr>
    <th>Maximum raffle tickets per person</th>
    <td>
      % if raffle.ticket_limit:
        ${raffle.ticket_limit}
      % else:
        Unlimited
      % endif
    </tr><tr>
    <th>Maximum prizes a person may win</th>
    <td>
      % if raffle.ticket_limit:
        ${raffle.winning_limit}
      % else:
        No limit
      % endif
    </td>
  </tr>
</table>

<div class="prize-display" style="float: right; border:1px solid #000; margin: 2ex; padding: 0.5ex;">
<% prize_seen = set() %>
% for prize in raffle.prizes:
  % if prize.prize_info_id not in prize_seen:
    % if len(prize.prize_info.images) > 1:
      <div class="thumbnail_bar">
        % for image in prize.prize_info.images:
          <img src="${tg.url('/prizes/thumbnail/%s' % image.id)}"
            onclick="show_prize_image('prize_image_${image.id}');"
            style="border:1px solid #00f;" />
        % endfor
      </div>
    % endif
    % for image in prize.prize_info.images:
      <p class="invisible prize_image" id="prize_image_${image.id}">
        <img src="${tg.url('/prizes/image/%s' % image.id)}" />
        ${image.caption}
      </p>
    % endfor
    <div>${prize.prize_info.description}</div>
  <% prize_seen.add(prize.prize_info_id) %>
  % endif
% endfor
</div>
<script type="text/javascript">
function show_prize_image(imgId) {
  jQuery('.prize_image').addClass('invisible');
  jQuery('#' + imgId).removeClass('invisible');

}
jQuery(document).ready(function() {
  jQuery('#prize_image_' + ${image.id}).removeClass('invisible');
});
</script>

<div style="clear:both;">
${raffle.description | n,entity,sanity_filter}
</div>

<hr width="76%"/>
% if raffle.groups or raffle.restrictions:
<h3>Restrictions</h3>
% if raffle.groups:
  <h4>Must be in one of these groups</h4>
  <ul>
    % for group in raffle.groups:
      % if group == 'cla + one':
        <li>You must have signed the cla and be in at least one other group</li>
      % else:
        <li>${group}</li>
      % endif
    % endfor
  </ul>
% endif
% if raffle.restrictions:
  <h4>Additional Restrictions</h4>
  ${raffle.restrictions| n,entity,sanity_filter}

  <p>
  If you don't meet the restrictions above, you will be able to enter the
  raffle but we will be unable to award you any prizes.
  </p>
% endif
% endif

<hr width="76%"/>
<p>
  <%
    msg = []
    disable = ''
    # Date okay?
    if raffle.start_date > now:
      msg.append('This raffle has not yet begun.')
    elif raffle.end_date < now:
      msg.append('This raffle has ended.')

    if tg.auth_stack_enabled and request.identity:
      # Line by line:
      # There is a ticket limit
      # User has entered tickets
      # User has entered the limit of tickets
      if raffle.ticket_limit and request.identity['user'].user_name in raffle.entrants and raffle.ticket_limit <= len(raffle.entrants[request.identity['user'].user_name]):
        msg.append('You have already entered the maximum number of times.')

    if msg:
      disable='disabled="true"'
  %>
  % if tg.auth_stack_enabled and request.identity:
    <form action="${tg.url('/enter_raffle/%s' % raffle.id)}" method="POST">
      <input type="submit" value="Enter me in raffle" ${disable} />
      % if msg:
        <span class="fielderror">${'  '.join(msg)}</span>
      % endif
    </form>
  % else:
    <form action="${tg.url('/login?came_from=%s' % tg.quote_plus('/raffle/%s' % raffle.id))}" method="POST">
      <input type="submit" value="You must login to enter raffles" ${disable} />
      % if msg:
        <span class="fielderror">${'  '.join(msg)}</span>
      % endif
    </form>
  % endif
</p>
<div class="clearingdiv" />
</div>
